@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006, 2007, 2009, 2010, 2011, 2012
+ * Copyright (C) 2006, 2007, 2009, 2010, 2011, 2012, 2013
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,8 +22,8 @@
 #include <cassert>
 
 #ifndef NDEBUG
-# include "msg.h"
-# include "str.h"
+# include "base/msg.h"
+# include "base/str.h"
 #endif
 
 #undef assert
