@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010, 2011, 2012
+ * Copyright (C) 2009, 2010, 2011, 2012, 2013
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,9 +22,9 @@
 #include <cstdlib>
 #include <cstdio>
 
-#include "dbg.h"
-#include "str.h"
-#include "msg.h"
+#include "base/dbg.h"
+#include "base/str.h"
+#include "base/msg.h"
 
 
 namespace msg
